"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const utils_aws_lambda_1 = require("@goldstack/utils-aws-lambda");
const assert_1 = __importDefault(require("assert"));
const generateLambdaConfig_1 = require("./generateLambdaConfig");
const templateLambdaApiBuild_1 = require("./templateLambdaApiBuild");
const dummyDeployment = {
    awsRegion: 'ap-east-1',
    awsUser: 'dummy',
    configuration: {
        lambdaNamePrefix: 'test-lambdas',
        apiDomain: 'domain',
        hostedZoneDomain: 'domain',
        lambdas: {},
    },
    name: 'test',
};
describe('Generate Lambda config', () => {
    const routesConfig = (0, utils_aws_lambda_1.readLambdaConfig)('./testData/routes-test');
    const config = (0, generateLambdaConfig_1.generateLambdaConfig)(dummyDeployment, routesConfig);
    test('Should render config for Terraform', () => {
        (0, assert_1.default)(config['default'].function_name);
        (0, assert_1.default)(config['ANY /folder/nested'].function_name.indexOf(dummyDeployment.configuration.lambdaNamePrefix || 'fail') !== -1);
    });
    test('Should determine correct output dirs for dist', () => {
        const nestedRoute = routesConfig.find((e) => e.path === '/folder/nested');
        (0, assert_1.default)(nestedRoute);
        const dir = (0, templateLambdaApiBuild_1.getOutDirForLambda)(nestedRoute);
        (0, assert_1.default)(dir === './distLambda/folder/nested');
    });
    test('Should determine path parametmers for file names', () => {
        const nestedRoute = routesConfig.find((e) => e.path === '/folder/{pathparam}');
        (0, assert_1.default)(nestedRoute);
        const functionName = (0, utils_aws_lambda_1.generateFunctionName)(dummyDeployment.configuration.lambdaNamePrefix, nestedRoute);
        (0, assert_1.default)(functionName.indexOf('folder') !== -1);
        (0, assert_1.default)(functionName.indexOf('{') === -1);
        (0, assert_1.default)(functionName.indexOf('}') === -1);
    });
    test('Should determine path parametmers for folder names', () => {
        const nestedRoute = routesConfig.find((e) => e.path === '/resource/{path}/object');
        (0, assert_1.default)(nestedRoute);
        const functionName = (0, utils_aws_lambda_1.generateFunctionName)(dummyDeployment.configuration.lambdaNamePrefix, nestedRoute);
        (0, assert_1.default)(functionName.indexOf('object') !== -1);
        (0, assert_1.default)(functionName.indexOf('resource') !== -1);
        (0, assert_1.default)(functionName.indexOf('{') === -1);
        (0, assert_1.default)(functionName.indexOf('}') === -1);
    });
    test('Should provide a correct path for a nested index file', () => {
        const nestedRoute = routesConfig.find((e) => e.path === '/health');
        (0, assert_1.default)(nestedRoute);
        const functionName = (0, utils_aws_lambda_1.generateFunctionName)(dummyDeployment.configuration.lambdaNamePrefix, nestedRoute);
        expect(functionName).toContain('health');
    });
    test('Should provide a correct path for a file in the API root', () => {
        var _a;
        const nestedRoute = routesConfig.find((e) => e.path === '/resource');
        (0, assert_1.default)(nestedRoute);
        const functionName = (0, utils_aws_lambda_1.generateFunctionName)(dummyDeployment.configuration.lambdaNamePrefix, nestedRoute);
        (0, assert_1.default)(((_a = functionName.match(/resource/g)) === null || _a === void 0 ? void 0 : _a.length) === 1);
    });
    test('Should hash long names', () => {
        const nestedRoute = routesConfig.find((e) => e.path === '/resource');
        (0, assert_1.default)(nestedRoute);
        const functionName = (0, utils_aws_lambda_1.generateFunctionName)('very_long_names_should_end_with_a_hash_and_never_be_longer_than_64_characters', nestedRoute);
        expect(functionName.length <= 64).toBeTruthy();
        expect(functionName.indexOf('characters') === -1).toBe(true);
    });
});
//# sourceMappingURL=generateLambdaConfig.spec.js.map