"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildLambdas = exports.getOutFileForLambda = exports.getOutDirForLambda = void 0;
const esbuild_1 = require("esbuild");
const esbuild_plugin_pnp_1 = require("@yarnpkg/esbuild-plugin-pnp");
const utils_sh_1 = require("@goldstack/utils-sh");
const getOutDirForLambda = (config) => {
    if (config.path === '$default') {
        return `./distLambda/${config.path}`;
    }
    return `./distLambda${config.path}`;
};
exports.getOutDirForLambda = getOutDirForLambda;
const getOutFileForLambda = (config) => {
    return `${(0, exports.getOutDirForLambda)(config)}/lambda.js`;
};
exports.getOutFileForLambda = getOutFileForLambda;
const buildLambdas = async (routesDir, configs) => {
    const esbuildConfig = (0, utils_sh_1.readToType)('./esbuild.config.json');
    for await (const config of configs) {
        (0, utils_sh_1.mkdir)('-p', (0, exports.getOutDirForLambda)(config));
        const esbuildLocalPath = (0, utils_sh_1.changeExtension)(`${routesDir}/${config.relativeFilePath}`, '.esbuild.config.json');
        const localEsbuildConfig = (0, utils_sh_1.readToType)(esbuildLocalPath);
        await (0, esbuild_1.build)({
            plugins: [(0, esbuild_plugin_pnp_1.pnpPlugin)()],
            bundle: true,
            entryPoints: [`${routesDir}/${config.relativeFilePath}`],
            external: ['aws-sdk'],
            minify: true,
            platform: 'node',
            format: 'cjs',
            target: 'node12.0',
            sourcemap: true,
            outfile: (0, exports.getOutFileForLambda)(config),
            ...esbuildConfig,
            ...localEsbuildConfig,
        });
    }
};
exports.buildLambdas = buildLambdas;
//# sourceMappingURL=templateLambdaApiBuild.js.map